@@ -1,7 +1,9 @@
 from ..core.client import APIAdaptor
-from ..core.mixins import (CRUDMixin, ListObjectMixin, PathMixin, SchemaObject)
+from ..core.schemas import SchemaObject
+from ..core.mixins import CRUDMixin, ListObjectMixin, PathMixin
 from .schemas import (
-    ApplicationSchema, ApplicationPatternSchema, ApplicationAddressSchema
+    ApplicationSchema, ApplicationPatternSchema, ApplicationAddressSchema,
+    ApplicationPrivilegeSchema
 )
 
 
@@ -10,6 +12,10 @@ __all__ = (
     'ApplicationList',
     'ApplicationPattern',
     'ApplicationPatternList',
+    'ApplicationAddress',
+    'ApplicationAddressList',
+    'ApplicationPrivilege',
+    'ApplicationPrivilegeList',
 )
 
 
@@ -42,7 +48,7 @@ class ApplicationList(APIAdaptor, ListObjectMixin, PathMixin):
     instance_class = Application
 
 
-class ApplicationPattern(APIAdaptor, CRUDMixin, PathMixin):
+class ApplicationPattern(CRUDMixin, SchemaObject, PathMixin, APIAdaptor):
     """
     Wrapper of ApplicationPattern to work with object over the API.
 
@@ -51,6 +57,7 @@ class ApplicationPattern(APIAdaptor, CRUDMixin, PathMixin):
         schema_class (MappingSchema): Mapping schema to serialize object.
     """
     path = 'patterns/{id}/'
+    path_create = 'patterns/create/'
     schema_class = ApplicationPatternSchema
 
 
@@ -68,7 +75,7 @@ class ApplicationPatternList(APIAdaptor, ListObjectMixin, PathMixin):
     instance_class = ApplicationPattern
 
 
-class ApplicationAddress(APIAdaptor, CRUDMixin, PathMixin):
+class ApplicationAddress(CRUDMixin, SchemaObject, PathMixin, APIAdaptor):
     """
     Wrapper of ApplicationAddress to work with object over the API.
 
@@ -77,6 +84,7 @@ class ApplicationAddress(APIAdaptor, CRUDMixin, PathMixin):
         schema_class (MappingSchema): Mapping schema to serialize object.
     """
     path = 'addresses/{id}/'
+    path_create = 'addresses/create/'
     schema_class = ApplicationAddressSchema
 
 
@@ -92,3 +100,30 @@ class ApplicationAddressList(APIAdaptor, ListObjectMixin, PathMixin):
     """
     path = 'addresses/'
     instance_class = ApplicationAddress
+
+
+class ApplicationPrivilege(APIAdaptor, CRUDMixin, SchemaObject, PathMixin):
+    """
+    Wrapper of ApplicationPrivilege to work with object over the API.
+
+    Attributes:
+        path (str): API url part to work over methods.
+        schema_class (MappingSchema): Mapping schema to serialize object.
+    """
+    path = 'privileges/{id}/'
+    path_create = 'privileges/create/'
+    schema_class = ApplicationPrivilegeSchema
+
+
+class ApplicationPrivilegeList(APIAdaptor, ListObjectMixin, PathMixin):
+    """
+    Wrapper over list of ApplicationPrivilege to work over the API with
+    multiple ApplicationPrivilege objects at the same time.
+
+    Attributes:
+        instance_class (object): Instance to serialize objects in the
+            list.
+        path (str): API url part to work over methods.
+    """
+    path = 'privileges/'
+    instance_class = ApplicationPrivilege
