@@ -6,13 +6,14 @@ from mauth.core.schemas import SchemaFields
 __all__ = (
     'ApplicationSchema',
     'ApplicationPatternSchema',
-    'ApplicationAddressSchema'
+    'ApplicationAddressSchema',
+    'ApplicationPrivilegeSchema'
 )
 
 
 class ApplicationSchema(colander.MappingSchema, SchemaFields):
     """
-    Application object serialization object.
+    Application object serialization schema.
 
     Attributes:
         api_key (Int): Application primary key.
@@ -49,10 +50,9 @@ class ApplicationPatternSchema(colander.MappingSchema, SchemaFields):
         application_id (Int): Application pattern application id(FK).
         regex (String): Application regex or full url to the server.
     """
-
     id = colander.SchemaNode(colander.Int(), missing=None)
 
-    application_id = colander.SchemaNode(colander.Int(), missing=None)
+    application = colander.SchemaNode(colander.Int(), missing=None)
     regex = colander.SchemaNode(colander.String(), missing='')
 
 
@@ -66,9 +66,25 @@ class ApplicationAddressSchema(colander.MappingSchema, SchemaFields):
         address (String): Application IP address.
         mask (Int): Application IP address mask
     """
-
     id = colander.SchemaNode(colander.Int(), missing=None)
 
-    application_id = colander.SchemaNode(colander.Int(), missing=None)
+    application = colander.SchemaNode(colander.Int(), missing=None)
     address = colander.SchemaNode(colander.String(), missing='')
     mask = colander.SchemaNode(colander.Int(), missing=None)
+
+
+class ApplicationPrivilegeSchema(colander.MappingSchema, SchemaFields):
+    """
+    Application's privilege serialization schema.
+
+    Attributes:
+        application_id (Int): Application id.
+        default_value (Boolean): Application privilege default user value.
+        id (Int): Application privilege id.
+        title (Str): Application privilege title.
+    """
+    id = colander.SchemaNode(colander.Int(), missing=None)
+
+    application = colander.SchemaNode(colander.Int(), missing=None)
+    title = colander.SchemaNode(colander.String(), missing='')
+    default_value = colander.SchemaNode(colander.Boolean(), missing=False)
